Class: Google::Api::CustomHttpPattern
- Inherits:
-
Object
- Object
- Google::Api::CustomHttpPattern
- Extended by:
- Protobug::Message
- Defined in:
- lib/google/api/http_pb.rb
Overview
A custom pattern is used for defining custom HTTP verb.
A custom pattern is used for defining custom HTTP verb.